@@ -4,8 +4,9 @@ import pkg_resources
 import json
 from typing import Any, Dict
 
-# Location of biobricks library
-CONFIG_FILE = '~/biobricks/config.json'
+# Location of biobricks
+BASE_DIR = '~/biobricks'
+CONFIG_FILE = BASE_DIR+'/config.json'
 
 # Current version
 def version():
@@ -21,10 +22,11 @@ def read_config() -> Dict[str, Any]:
         return json.load(f)
 
 def write_config(config: Dict[str, Any]) -> None:
-    with open(CONFIG_FILE, 'x') as f:
+    with open(CONFIG_FILE, 'w') as f:
         json.dump(config, f)
 
 def initialize() -> None:
+    os.makedirs(BASE_DIR, exist_ok=True)
     if exists(CONFIG_FILE):
         config = read_config()
     else:
@@ -32,17 +34,14 @@ def initialize() -> None:
         if bblib:
             library = bblib
         else:
-            library = '~/biobricks/library'
+            library = BASE_DIR+'/library'
         config = {
             'library': library,
         }
         write_config(config)
     globals().update(config)
-    if not exists(library):
-        os.system(f"mkdir -p {library}")
+    os.makedirs(library, exist_ok=True)
+    os.makedirs(library+"/cache", exist_ok=True)
     if not exists(library+"/.git"):
         os.system(f"cd {library}; git init")
-    if not exists(library+"/cache"):
-        os.system(f"cd {library}; mkdir -p cache")
-    print(f"Initialized BioBricks library to {library}.")
-
+    print(f"Initialized BioBricks library to {library}.")
\ No newline at end of file
